@@ -5,7 +5,7 @@ use SVN::Client;
 
 extends 'VCI';
 
-our $VERSION = '0.2.1';
+our $VERSION = '0.3.0_1';
 
 has 'x_client' => (is => 'ro', isa => 'SVN::Client', lazy => 1,
                    default => sub { shift->build_x_client });
@@ -68,6 +68,10 @@ Listed here are other limitations of VCI::VCS::Svn compared to the general
 API specified in the C<VCI::Abstract> modules (or compared to how you might
 expect the driver to function):
 
+=head2 VCI::VCS::Svn::Project
+
+Svn supports L<"root_project"|VCI::Abstract::Project/root_project>.
+
 =head2 VCI::VCS::Svn::Commit
 
 =over
